"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Breakpoints: () => Breakpoints,
  ColorCategories: () => ColorCategories,
  ColorTokens: () => ColorTokens,
  DefaultTheme: () => DefaultTheme,
  HeadingLevel: () => HeadingLevel,
  Sizing: () => Sizing,
  TextSize: () => TextSize,
  ThemeColor: () => ThemeColor,
  ThemeContext: () => ThemeContext,
  ThemeMapperStates: () => ThemeMapperStates,
  ThemeMapperStyles: () => ThemeMapperStyles,
  ThemeProperties: () => ThemeProperties,
  UiConfirmDialogContext: () => UiConfirmDialogContext,
  UiDialogsControllerContext: () => UiDialogsControllerContext,
  UiNotificationsContext: () => UiNotificationsContext,
  UiSpacing: () => UiSpacing,
  UiViewport: () => UiViewport,
  getColorCategory: () => getColorCategory,
  getColorTokenValue: () => getColorTokenValue,
  getHeadingSize: () => getHeadingSize,
  getNextColorToken: () => getNextColorToken,
  getSpacingSize: () => getSpacingSize,
  getSpacingStyle: () => getSpacingStyle,
  getTextSize: () => getTextSize,
  getTextSizeFromSizeString: () => getTextSizeFromSizeString,
  getThemeColor: () => getThemeColor,
  getThemeStyling: () => getThemeStyling,
  useConfirmDialogController: () => useConfirmDialogController,
  useDialogController: () => useDialogController,
  useNotificationsController: () => useNotificationsController,
  useViewport: () => useViewport
});
module.exports = __toCommonJS(src_exports);

// src/hooks/use-dialogs-controller.ts
var import_react = __toESM(require("react"));
var useDialogController = () => {
  const [openedDialogs, setOpenedDialogs] = import_react.default.useState([]);
  const openDialog = import_react.default.useCallback(
    (dialogId) => {
      const found = openedDialogs.filter((id) => id === dialogId);
      if (!found || found.length === 0) {
        const newOpenedDialogs = [...openedDialogs, dialogId];
        setOpenedDialogs(newOpenedDialogs);
      }
    },
    [openedDialogs, setOpenedDialogs]
  );
  const closeDialog = import_react.default.useCallback(
    (dialogId) => {
      const newOpenedDialogs = openedDialogs.filter((id) => id !== dialogId);
      setOpenedDialogs(newOpenedDialogs);
    },
    [openedDialogs, setOpenedDialogs]
  );
  return {
    openDialog,
    closeDialog,
    openedDialogs
  };
};

// src/hooks/use-window-dimensions.ts
var import_react2 = require("react");

// src/responsive/breakpoints-sizes.ts
var BreakpointsSizes = {
  s: {
    max: 579
  },
  m: {
    min: 580,
    max: 991
  },
  l: {
    min: 992,
    max: 1440
  },
  xl: {
    min: 1440
  }
};

// src/hooks/utils/get-window-deimensions.ts
var getWindowDimensions = () => {
  if (typeof window !== "undefined") {
    const { innerWidth: width, innerHeight: height } = window;
    return {
      width,
      height
    };
  }
  return {
    width: BreakpointsSizes.l.min,
    height: BreakpointsSizes.l.min
  };
};

// src/hooks/use-window-dimensions.ts
var useWindowDimensions = () => {
  const [windowDimensions, setWindowDimensions] = (0, import_react2.useState)(getWindowDimensions());
  (0, import_react2.useEffect)(() => {
    const handleResize = () => {
      setWindowDimensions(getWindowDimensions());
    };
    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, []);
  (0, import_react2.useEffect)(() => {
    setWindowDimensions(getWindowDimensions());
  }, []);
  return windowDimensions;
};

// src/hooks/use-viewport.ts
var import_react3 = require("react");
var useViewport = () => {
  const { width } = useWindowDimensions();
  const [hydratred, setHydrated] = (0, import_react3.useState)(false);
  const viewportResponse = (0, import_react3.useMemo)(() => {
    const isSmall = width <= BreakpointsSizes.s.max;
    const isMedium = width >= BreakpointsSizes.m.min && width <= BreakpointsSizes.m.max;
    const isLarge = width >= BreakpointsSizes.l.min && width <= BreakpointsSizes.l.max;
    const isXLarge = width >= BreakpointsSizes.xl.min;
    return {
      isSmall,
      isMedium,
      isLarge,
      isXLarge
    };
  }, [width]);
  (0, import_react3.useEffect)(() => {
    setHydrated(true);
  }, []);
  if (hydratred) {
    return viewportResponse;
  }
  return {
    isSmall: false,
    isMedium: false,
    isLarge: true,
    isXLarge: false
  };
};

// src/hooks/use-notitications-controller.ts
var import_react4 = require("react");
var useNotificationsController = () => {
  const [notifications, setNotifications] = (0, import_react4.useState)([]);
  const showNotification = (0, import_react4.useCallback)(
    (notification) => {
      setNotifications([...notifications, notification]);
    },
    [notifications, setNotifications]
  );
  return {
    notifications,
    showNotification
  };
};

// src/hooks/use-confirm-dialog-controller.ts
var import_react5 = require("react");
var useConfirmDialogController = () => {
  const [visible, setVisible] = (0, import_react5.useState)(false);
  const [confirmDialogData, setConfirmDialogData] = (0, import_react5.useState)(null);
  const hideConfirmDialog = (0, import_react5.useCallback)(() => {
    setVisible(false);
  }, [setVisible]);
  const showConfirmDialog = (0, import_react5.useCallback)(
    (data, onConfirm, onDeny, options) => {
      setVisible(true);
      setConfirmDialogData({
        data,
        confirm: onConfirm,
        deny: onDeny,
        options
      });
    },
    [confirmDialogData, setConfirmDialogData]
  );
  return {
    visible,
    confirmDialog: confirmDialogData,
    showConfirmDialog,
    hideConfirmDialog
  };
};

// src/providers/dialogs-context.ts
var import_react6 = __toESM(require("react"));
var noOpDialogControl = () => {
  console.error("No dialog controller implemented");
};
var UiDialogsControllerContext = import_react6.default.createContext({
  openDialog: noOpDialogControl,
  closeDialog: noOpDialogControl,
  openedDialogs: []
});
UiDialogsControllerContext.displayName = "UiDialogsControllerContext";

// src/providers/theme-context.ts
var import_react7 = __toESM(require("react"));

// src/themes/default-colors/dark.ts
var Dark = {
  fonts: {
    token_10: "#ffffff",
    token_50: "#f0f0f0",
    token_100: "#e0dede",
    token_150: "#c9c9c9",
    token_200: "#b3b3b3"
  },
  primary: {
    token_10: "#2F343D",
    token_50: "#272B33",
    token_100: "#23272F",
    token_150: "#1F242C",
    token_200: "#171B21"
  },
  secondary: {
    token_10: "#575D68",
    token_50: "#494E57",
    token_100: "#40454D",
    token_150: "#363B44",
    token_200: "#2C3139"
  },
  tertiary: {
    token_10: "#e67e20",
    token_50: "#d46d0f",
    token_100: "#C66002",
    token_150: "#ab5300",
    token_200: "#8f4601"
  },
  positive: {
    token_10: "#67b879",
    token_50: "#49a35d",
    token_100: "#368f4a",
    token_150: "#278c3e",
    token_200: "#186e2c"
  },
  negative: {
    token_10: "#a6a4a4",
    token_50: "#827f7f",
    token_100: "#636161",
    token_150: "#424141",
    token_200: "#1c1b1b"
  },
  error: {
    token_10: "#c21f1f",
    token_50: "#a82020",
    token_100: "#911919",
    token_150: "#6b1212",
    token_200: "#470b0b"
  },
  warning: {
    token_10: "#e0d902",
    token_50: "#b5af02",
    token_100: "#948f01",
    token_150: "#757105",
    token_200: "#575406"
  }
};

// src/themes/default-colors/light.ts
var Light = {
  fonts: {
    token_10: "#6e6e6e",
    token_50: "#444544",
    token_100: "#282928",
    token_150: "#262626",
    token_200: "#0a0a0a"
  },
  primary: {
    token_10: "#EFFAE5",
    token_50: "#E9F5DE",
    token_100: "#E0ECD5",
    token_150: "#D8E5CC",
    token_200: "#D1DFC3"
  },
  secondary: {
    token_10: "#D0F1AF",
    token_50: "#C5E8A2",
    token_100: "#BEE19B",
    token_150: "#B5D992",
    token_200: "#ACD188"
  },
  tertiary: {
    token_10: "#58d9f5",
    token_50: "#4ad8f7",
    token_100: "#3EDAFC",
    token_150: "#30bddb",
    token_200: "#2197b0"
  },
  positive: {
    token_10: "#62fc84",
    token_50: "#45DC66",
    token_100: "#30BF4F",
    token_150: "#2CAF49",
    token_200: "#1c8032"
  },
  negative: {
    token_10: "#e3e3e3",
    token_50: "#B5B4B4",
    token_100: "#9B9A9A",
    token_150: "#7C7C7C",
    token_200: "#595858"
  },
  error: {
    token_10: "#f7a3a3",
    token_50: "#FF8181",
    token_100: "#FD6A6A",
    token_150: "#FF5A5A",
    token_200: "#de3737"
  },
  warning: {
    token_10: "#fcf651",
    token_50: "#DED802",
    token_100: "#C8C204",
    token_150: "#BFB903",
    token_200: "#8a8601"
  }
};

// src/themes/default-theme.ts
var DefaultTheme = {
  name: "UIReactDefaultTheme",
  dark: Dark,
  light: Light,
  sizes: {
    headings: {
      level1: "26px",
      level2: "24px",
      level3: "20px",
      level4: "18px",
      level5: "18px",
      level6: "18px"
    },
    texts: {
      xsmall: "14px",
      small: "16px",
      regular: "18px",
      large: "20px",
      xlarge: "22px"
    }
  },
  texts: {
    font: `'Source Sans Pro', sans- serif`
  },
  spacing: {
    one: "1px",
    two: "2px",
    three: "4px",
    four: "8px",
    five: "16px",
    six: "32px",
    seven: "64px"
  }
};

// src/types/enums/color-categories.ts
var ColorCategories = /* @__PURE__ */ ((ColorCategories3) => {
  ColorCategories3["fonts"] = "fonts";
  ColorCategories3["primary"] = "primary";
  ColorCategories3["secondary"] = "secondary";
  ColorCategories3["tertiary"] = "tertiary";
  ColorCategories3["positive"] = "positive";
  ColorCategories3["negative"] = "negative";
  ColorCategories3["error"] = "error";
  ColorCategories3["warning"] = "warning";
  return ColorCategories3;
})(ColorCategories || {});

// src/themes/get-color-category.ts
var getColorCategory = (category) => {
  switch (category) {
    case "error":
      return "error" /* error */;
    case "warning":
      return "warning" /* warning */;
    case "negative":
      return "negative" /* negative */;
    case "positive":
      return "positive" /* positive */;
    case "primary":
      return "primary" /* primary */;
    case "secondary":
      return "secondary" /* secondary */;
    case "tertiary":
      return "tertiary" /* tertiary */;
    default:
      return "fonts" /* fonts */;
  }
};

// src/types/breakpoints-enum.ts
var Breakpoints = /* @__PURE__ */ ((Breakpoints2) => {
  Breakpoints2[Breakpoints2["SMALL"] = 0] = "SMALL";
  Breakpoints2[Breakpoints2["MEDIUM"] = 1] = "MEDIUM";
  Breakpoints2[Breakpoints2["LARGE"] = 2] = "LARGE";
  Breakpoints2[Breakpoints2["XLARGE"] = 3] = "XLARGE";
  return Breakpoints2;
})(Breakpoints || {});

// src/types/enums/color-tokens.ts
var ColorTokens = /* @__PURE__ */ ((ColorTokens3) => {
  ColorTokens3["token_10"] = "token_10";
  ColorTokens3["token_50"] = "token_50";
  ColorTokens3["token_100"] = "token_100";
  ColorTokens3["token_150"] = "token_150";
  ColorTokens3["token_200"] = "token_200";
  return ColorTokens3;
})(ColorTokens || {});

// src/types/enums/heading-levels.ts
var HeadingLevel = /* @__PURE__ */ ((HeadingLevel2) => {
  HeadingLevel2["level1"] = "level1";
  HeadingLevel2["level2"] = "level2";
  HeadingLevel2["level3"] = "level3";
  HeadingLevel2["level4"] = "level4";
  HeadingLevel2["level5"] = "level5";
  HeadingLevel2["level6"] = "level6";
  return HeadingLevel2;
})(HeadingLevel || {});

// src/types/enums/spacing.ts
var Sizing = /* @__PURE__ */ ((Sizing2) => {
  Sizing2["one"] = "one";
  Sizing2["two"] = "two";
  Sizing2["three"] = "three";
  Sizing2["four"] = "four";
  Sizing2["five"] = "five";
  Sizing2["six"] = "six";
  Sizing2["seven"] = "seven";
  return Sizing2;
})(Sizing || {});

// src/types/enums/theme-color.ts
var ThemeColor = /* @__PURE__ */ ((ThemeColor2) => {
  ThemeColor2["light"] = "light";
  ThemeColor2["dark"] = "dark";
  return ThemeColor2;
})(ThemeColor || {});

// src/types/enums/text-size.ts
var TextSize = /* @__PURE__ */ ((TextSize3) => {
  TextSize3["xsmall"] = "xsmall";
  TextSize3["small"] = "small";
  TextSize3["regular"] = "regular";
  TextSize3["large"] = "large";
  TextSize3["xlarge"] = "xlarge";
  return TextSize3;
})(TextSize || {});

// src/types/themes/theme.ts
var ThemeProperties = /* @__PURE__ */ ((ThemeProperties2) => {
  ThemeProperties2["name"] = "name";
  ThemeProperties2["texts"] = "texts";
  ThemeProperties2["sizes"] = "sizes";
  ThemeProperties2["light"] = "light";
  ThemeProperties2["dark"] = "dark";
  ThemeProperties2["spacing"] = "spacing";
  return ThemeProperties2;
})(ThemeProperties || {});

// src/types/theme-mapper.ts
var ThemeMapperStates = /* @__PURE__ */ ((ThemeMapperStates2) => {
  ThemeMapperStates2["normal"] = "normal";
  ThemeMapperStates2["hover"] = "hover";
  ThemeMapperStates2["active"] = "active";
  ThemeMapperStates2["selected"] = "selected";
  ThemeMapperStates2["disabled"] = "disabled";
  ThemeMapperStates2["visited"] = "visited";
  ThemeMapperStates2["focus"] = "focus";
  return ThemeMapperStates2;
})(ThemeMapperStates || {});
var ThemeMapperStyles = /* @__PURE__ */ ((ThemeMapperStyles3) => {
  ThemeMapperStyles3["color"] = "color";
  ThemeMapperStyles3["background"] = "background";
  ThemeMapperStyles3["borderColor"] = "border-color";
  ThemeMapperStyles3["fill"] = "fill";
  return ThemeMapperStyles3;
})(ThemeMapperStyles || {});

// src/themes/get-color-token.ts
var getColorTokenValue = (token) => {
  switch (token) {
    case "10": {
      return "token_10" /* token_10 */;
    }
    case "50": {
      return "token_50" /* token_50 */;
    }
    case "100": {
      return "token_100" /* token_100 */;
    }
    case "150": {
      return "token_150" /* token_150 */;
    }
    case "200": {
      return "token_200" /* token_200 */;
    }
    default: {
      return "token_100" /* token_100 */;
    }
  }
};

// src/themes/get-next-theme-token.ts
var getNextColorToken = (token) => {
  switch (token) {
    case "token_10" /* token_10 */:
      return "token_50" /* token_50 */;
    case "token_50" /* token_50 */:
      return "token_100" /* token_100 */;
    case "token_100" /* token_100 */:
      return "token_150" /* token_150 */;
    case "token_150" /* token_150 */:
      return "token_200" /* token_200 */;
    case "token_200" /* token_200 */:
      return "token_200" /* token_200 */;
    default:
      return "token_100" /* token_100 */;
  }
};

// src/themes/get-theme-color.ts
var getThemeColor = (theme, $selectedTheme, category, token, inverse) => {
  var _a, _b, _c, _d, _e, _f;
  if (inverse) {
    if ($selectedTheme === "dark" /* dark */) {
      return ((_b = (_a = theme == null ? void 0 : theme["light" /* light */]) == null ? void 0 : _a[category]) == null ? void 0 : _b[token]) || "";
    } else {
      return ((_d = (_c = theme == null ? void 0 : theme["dark" /* dark */]) == null ? void 0 : _c[category]) == null ? void 0 : _d[token]) || "";
    }
  }
  return ((_f = (_e = theme == null ? void 0 : theme[$selectedTheme]) == null ? void 0 : _e[category]) == null ? void 0 : _f[token]) || "";
};

// src/themes/get-theme-styling.ts
var getThemeStyling = (theme, selectedTheme, mapper) => {
  let style = "";
  Object.keys(mapper).map((state) => {
    let stateStyling = "";
    const themeState = mapper[state];
    themeState && Object.keys(themeState).map((styleProperty) => {
      var _a;
      const mapperValue = themeState[styleProperty];
      const currentTheme = (mapperValue == null ? void 0 : mapperValue.inverse) ? theme[selectedTheme === "dark" /* dark */ ? "light" /* light */ : "dark" /* dark */] : theme[selectedTheme];
      const tokenValue = mapperValue && ((_a = currentTheme[mapperValue.category]) == null ? void 0 : _a[mapperValue.token]);
      if (!tokenValue) {
        return;
      }
      stateStyling = `${stateStyling}${styleProperty}: ${tokenValue};
`;
    });
    if (state !== "normal" /* normal */) {
      style = `${style} &:${state} {
${stateStyling}}
`;
    } else {
      style = `${style}${stateStyling}
`;
    }
  });
  return style;
};

// src/themes/get-theme-size.ts
var getHeadingSize = (theme, level) => {
  let headingLevel = "level3" /* level3 */;
  switch (level) {
    case 1:
      headingLevel = "level1" /* level1 */;
      break;
    case 2:
      headingLevel = "level2" /* level2 */;
      break;
    case 3:
      headingLevel = "level3" /* level3 */;
      break;
    case 4:
      headingLevel = "level4" /* level4 */;
      break;
    case 5:
      headingLevel = "level5" /* level5 */;
      break;
    case 6:
      headingLevel = "level6" /* level6 */;
      break;
    default:
      headingLevel = "level3" /* level3 */;
      break;
  }
  return theme.sizes.headings[headingLevel];
};
var getTextSize = (theme, size) => {
  return theme.sizes.texts[size];
};
var getTextSizeFromSizeString = (theme, size) => {
  return theme.sizes.texts[size];
};
var getSpacingSize = (theme, size) => {
  return theme.spacing[size];
};

// src/providers/theme-context.ts
var ThemeContext = import_react7.default.createContext({
  theme: DefaultTheme,
  selectedTheme: "light" /* light */
});
ThemeContext.displayName = "UiReactThemeContext";

// src/providers/notifications-context.ts
var import_react8 = __toESM(require("react"));
var noOpNotification = () => {
  console.error("No show notification fn implemented");
};
var UiNotificationsContext = import_react8.default.createContext({
  showNotification: noOpNotification,
  notifications: []
});
UiNotificationsContext.displayName = "UiNotificationsContext";

// src/providers/confirm-dialog-context.ts
var import_react9 = __toESM(require("react"));
var noOp = () => {
  console.error("No confirm dialog fn implemented");
};
var UiConfirmDialogContext = import_react9.default.createContext({
  showConfirmDialog: noOp,
  hideConfirmDialog: noOp,
  visible: false,
  confirmDialog: null
});
UiConfirmDialogContext.displayName = "UiConfirmDialogContext";

// src/responsive/viewport.tsx
var React6 = __toESM(require("react"));
var UiViewport = ({ children, criteria, skipSSr }) => {
  const [hydrated, setHydrated] = React6.useState(false);
  const { isSmall, isMedium, isLarge, isXLarge } = useViewport();
  React6.useEffect(() => {
    setHydrated(true);
  }, []);
  if (skipSSr && !hydrated) {
    return null;
  }
  if (!hydrated) {
    const isCriteriaLarge = criteria === 2 /* LARGE */ || criteria === "m|l" || criteria === "l|xl" || criteria === "m|l|xl";
    const isCriteriaXLarge = criteria === 3 /* XLARGE */ || criteria === "l|xl" || criteria === "m|l|xl";
    if (isCriteriaLarge || isCriteriaXLarge) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
    return null;
  }
  if (isSmall) {
    const matchesCriteria = criteria === 0 /* SMALL */ || criteria === "s|m";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  if (isMedium) {
    const matchesCriteria = criteria === 1 /* MEDIUM */ || criteria === "s|m" || criteria === "m|l" || criteria === "m|l|xl";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  if (isLarge) {
    const matchesCriteria = criteria === 2 /* LARGE */ || criteria === "m|l" || criteria === "l|xl" || criteria === "m|l|xl";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  if (isXLarge) {
    const matchesCriteria = criteria === 3 /* XLARGE */ || criteria === "l|xl" || criteria === "m|l|xl";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  return null;
};
UiViewport.displayName = "UiViewport";

// src/spacing/spacing.tsx
var React7 = __toESM(require("react"));
var import_styled_components = __toESM(require("styled-components"));
var getSpacingStyle = (sizing) => {
  if (sizing.all) {
    return `var(--spacing-${sizing.all})`;
  }
  if (sizing.inline || sizing.block) {
    const blockValue = sizing.block ? `var(--spacing-${sizing.block})` : "0px";
    const inlineValue = sizing.inline ? `var(--spacing-${sizing.inline})` : "0px";
    return `${blockValue} ${inlineValue}`;
  }
  return `
    ${sizing.top ? `var(--spacing-${sizing.top})` : "0px"}
    ${sizing.right ? `var(--spacing-${sizing.right})` : "0px"}
    ${sizing.bottom ? `var(--spacing-${sizing.bottom})` : "0px"}
    ${sizing.left ? `var(--spacing-${sizing.left})` : "0px"}
  `;
};
var Div = import_styled_components.default.div`
  ${(props) => `
    ${props.$margin ? `margin: ${getSpacingStyle(props.$margin)};` : ""}
    ${props.$padding ? `padding: ${getSpacingStyle(props.$padding)};` : ""}
    ${props.$inline ? "display: inline-block" : ""}
  `}
`;
var UiSpacing = ({
  children,
  className,
  inline,
  margin,
  padding,
  testId
}) => /* @__PURE__ */ React7.createElement(Div, { $inline: inline, $margin: margin, $padding: padding, className, "data-testid": testId }, children);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Breakpoints,
  ColorCategories,
  ColorTokens,
  DefaultTheme,
  HeadingLevel,
  Sizing,
  TextSize,
  ThemeColor,
  ThemeContext,
  ThemeMapperStates,
  ThemeMapperStyles,
  ThemeProperties,
  UiConfirmDialogContext,
  UiDialogsControllerContext,
  UiNotificationsContext,
  UiSpacing,
  UiViewport,
  getColorCategory,
  getColorTokenValue,
  getHeadingSize,
  getNextColorToken,
  getSpacingSize,
  getSpacingStyle,
  getTextSize,
  getTextSizeFromSizeString,
  getThemeColor,
  getThemeStyling,
  useConfirmDialogController,
  useDialogController,
  useNotificationsController,
  useViewport
});
